@@ -24,6 +24,18 @@ lazy_static! {
 }
 
 
+/// Supported ANSI output formats
+#[derive(Debug, Copy, Clone, Hash, PartialEq, Eq, PartialOrd, Ord)]
+pub enum AnsiOutputFormat {
+    /// Truecolor ANSI 24-bit colour
+    Truecolor,
+    /// Dumb ANSI 3-bit colour, for black backgrounds
+    SimpleBlack,
+    /// Dumb ANSI 3-bit colour, for white backgrounds
+    SimpleWhite,
+}
+
+
 /// Representation of the application's all configurable values.
 #[derive(Debug, Clone, Hash, PartialEq, Eq)]
 pub struct Options {
@@ -35,12 +47,8 @@ pub struct Options {
     pub size: (u32, u32),
     /// Whether to preserve the image's aspect ratio when resizing. Default: `true`.
     pub preserve_aspect: bool,
-    /// Whether to output ANSI escapes. Default: `None` on Windooze when not writing to a file.
-    ///
-    /// `None` -- WinAPI
-    /// `Some(true)` -- truecolor ANSI 24-bit colour
-    /// `Some(false)` -- dumb ANSI 3-bit colour
-    pub ansi_out: Option<bool>,
+    /// Whether to output ANSI escapes and in which format. Default: `None` on Windooze when not writing to a file.
+    pub ansi_out: Option<AnsiOutputFormat>,
 }
 
 impl Options {
@@ -62,7 +70,7 @@ impl Options {
             .arg(Arg::from_usage("<IMAGE> 'Image file to display'").validator(Options::image_file_validator))
             .arg(szarg)
             .arg(Arg::from_usage("-f --force 'Don\\'t preserve the image\\'s aspect ratio'"))
-            .arg(Arg::from_usage("-a --ansi [ANSI] 'Force output ANSI escapes'").possible_values(&["simple", "truecolor"]))
+            .arg(Arg::from_usage("-a --ansi [ANSI] 'Force output ANSI escapes'").possible_values(&["truecolor", "simple-black", "simple-white"]))
             .get_matches();
 
         let image = matches.value_of("IMAGE").unwrap();
@@ -72,8 +80,9 @@ impl Options {
             preserve_aspect: !matches.is_present("force"),
             ansi_out: if cfg!(not(target_os = "windows")) || !have_dimms || matches.is_present("ansi") {
                 match matches.value_of("ansi").unwrap_or("truecolor") {
-                    "simple" => Some(false),
-                    "truecolor" => Some(true),
+                    "truecolor" => Some(AnsiOutputFormat::Truecolor),
+                    "simple-black" => Some(AnsiOutputFormat::SimpleBlack),
+                    "simple-white" => Some(AnsiOutputFormat::SimpleWhite),
                     _ => unreachable!(),
                 }
             } else {
